# EPL-data-board

![alt EPL logo](./static/assets/logoright.png)

#### English Premier League data is extracted through [Football-Data](https://www.football-data.org/) and created a basic page for football enthusiast and fans to provide them reliable data and  information about the EPL.

---

```
1. install django and python3 in your system 
```

```
2. git clone https://github.com/Kshitiz-Mhto/EPL-data-board.git
```

```
3. goto EPL-data-board directory
```

> copy the code below and paste in the terminal.

```
python3 manage.py runserver
```

> basically, the webpage will be at localhost:8000/ and for ` custom port `

```
python3 manage.py runserver <custom-port>
```
